==> pointpos_api-0.0.16.tar.gz: test/purchase_order_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for PurchaseOrderApi
void main() {
  var instance = new PurchaseOrderApi();

  group('tests for PurchaseOrderApi', () {
    // Create Purchaseorder
    //
    // Create Purchaseorder
    //
    //Future<PurchaseOrder> createPurchaseorder(String authorization, String xAPIKey, PurchaseOrder body, { String xPin }) async 
    test('test createPurchaseorder', () async {
      // TODO
    });

    // Delete Purchaseorder By ID
    //
    // Delete Purchaseorder By ID
    //
    //Future deletePurchaseorderByID(String authorization, String xAPIKey, String outletId, { String xPin }) async 
    test('test deletePurchaseorderByID', () async {
      // TODO
    });

    // Get Purchaseorder List
    //
    // Get Purchaseorder  List
    //
    //Future<List<PurchaseOrder>> findPurchaseorder(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findPurchaseorder', () async {
      // TODO
    });

    // Get Purchaseorder By ID
    //
    // Get Purchaseorder By ID
    //
    //Future<PurchaseOrder> getPurchaseorderByID(String authorization, String xAPIKey, String outletId, { String xPin }) async 
    test('test getPurchaseorderByID', () async {
      // TODO
    });

    // Update Purchaseorder By ID
    //
    // Update [object Object] By ID
    //
    //Future<PurchaseOrder> updatePurchaseorderByID(String authorization, String xAPIKey, String outletId, PurchaseOrder body, { String xPin }) async 
    test('test updatePurchaseorderByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.0.tar.gz: test/purchase_order_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for PurchaseOrderApi
void main() {
  var instance = new PurchaseOrderApi();

  group('tests for PurchaseOrderApi', () {
    // Create Purchaseorder
    //
    // Create Purchaseorder
    //
    //Future<PurchaseOrder> createPurchaseorder(String authorization, String xAPIKey, PurchaseOrder body, { String xPin }) async 
    test('test createPurchaseorder', () async {
      // TODO
    });

    // Delete Purchaseorder By ID
    //
    // Delete Purchaseorder By ID
    //
    //Future deletePurchaseorderByID(String authorization, String xAPIKey, String outletId, { String xPin }) async 
    test('test deletePurchaseorderByID', () async {
      // TODO
    });

    // Get Purchaseorder List
    //
    // Get Purchaseorder  List
    //
    //Future<List<PurchaseOrder>> findPurchaseorder(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findPurchaseorder', () async {
      // TODO
    });

    // Get Purchaseorder By ID
    //
    // Get Purchaseorder By ID
    //
    //Future<PurchaseOrder> getPurchaseorderByID(String authorization, String xAPIKey, String outletId, { String xPin }) async 
    test('test getPurchaseorderByID', () async {
      // TODO
    });

    // Update Purchaseorder By ID
    //
    // Update [object Object] By ID
    //
    //Future<PurchaseOrder> updatePurchaseorderByID(String authorization, String xAPIKey, String outletId, PurchaseOrder body, { String xPin }) async 
    test('test updatePurchaseorderByID', () async {
      // TODO
    });

  });
}
